#
# spec file for package python-django-upgrade
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-django-upgrade
Version:        1.22.2
Release:        1.1
Summary:        Automatically upgrade your Django projects
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/adamchainz/django-upgrade
Source:         https://github.com/adamchainz/django-upgrade/archive/refs/tags/%{version}.tar.gz#/django-upgrade-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-tokenize-rt
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     python-setuptools
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module tokenize-rt}
# /SECTION
%python_subpackages

%description
Automatically upgrade your Django projects.

%prep
%setup -q -n django-upgrade-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/django-upgrade
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative django-upgrade

%postun
%python_uninstall_alternative django-upgrade

%check
%pytest -k 'not test_main_version'

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/django-upgrade
%{python_sitelib}/django[_-]upgrade*/

%changelog
* Thu Dec  5 2024 Dirk Müller <dmueller@suse.com>
- update to 1.22.2:
  * Make these fixers work when django.contrib.gis.db.models is
    used to import objects from django.db.models:
    check_constraint_condition index_together  Issue #513.
* Mon Oct 28 2024 Dirk Müller <dmueller@suse.com>
- update to 1.22.1:
  * Fix circular import error when running django-upgrade. Thanks
    to Michal Čihař for the report in Issue #503.
  * Avoid accidental removal of comments a removed if block in
    the versioned block fixer. Thanks to Tobias Funke for the
    report in Issue #495.
  * Add all-version fixer to remove outdated test skip
    decorators. Issue #364.
  * Drop Python 3.8 support.
  * Support Python 3.13.
  * Add Django 5.0+ fixer to rewrite format_html() calls without
    args or kwargs probably using str.format() incorrectly. Issue
    [#477].
* Sat Aug 31 2024 Dirk Müller <dmueller@suse.com>
- update to 1.20.0:
  * Fix the admin_register fixer to avoid rewriting when there
    are duplicate ModelAdmin classes in the file. Issue #471.
* Mon Jul  8 2024 Dirk Müller <dmueller@suse.com>
- update to 1.19.0:
  * Add Django 4.2+ fixer to rewrite index_together declarations
    into indexes declarations in model Meta classes. This fixer
    can make changes that require migrations. Add a test for
    pending migrations to ensure that you do not miss these. PR
    [#464].
  * Fix tracking of AST node parents. This may have fixed some
    subtle bugs in these fixers:  admin_register
    assert_form_error default_app_config management_commands
    request_headers settings_database_postgresql
    settings_storages testcase_databases use_l10n utils_timezone
  * If you see any new changes, or had them previously disabled,
    please report an issue so we can extra tests to the test
    suite.
* Wed Jun 12 2024 Dirk Müller <dmueller@suse.com>
- update to 1.18.0:
  * Support Django 5.1 as a target version.
  * Add Django 5.1+ fixer to rewrite the check keyword argument
    of CheckConstraint to condition.
  * Add fixer selection options: --only <name>, --skip <name>,
    and --list-fixers.
* Sun Apr  7 2024 Dirk Müller <dmueller@suse.com>
- update to 1.16.0:
  * Remove the Django 5.0+ fixer that dropped .choices from model
    field choices parameters. It was too unreliable because it
    could break use for “DIY” enumeration types.
  * Remove the Django 5.0+ fixer that dropped .choices from model
    field choices parameters. It was too unreliable because it
    could break use for “DIY” enumeration types.
  * Add Django 1.10+ fixer to rewrite request.user functions that
    changed to boolean attributes: is_authenticated and
    is_anonymous.
  * Add Django 1.10+ fixer to rewrite request.user functions that
    changed to boolean attributes: is_authenticated and
    is_anonymous.
  * Add Django 2.0+ imports fixes for names moved from
    django.core.urlresolvers to django.urls.
  * Add Django 2.0+ imports fixes for names moved from
    django.core.urlresolvers to django.urls.
* Sat Dec  2 2023 Dirk Müller <dmueller@suse.com>
- update to 1.15.0:
  * Support Django 5.0 as a target version.
  * Add Django 5.0+ fixer to drop ``.choices`` on model field
    ``choices`` parameters when using an enumeration type.
  * Add some compatibility import replacements for Django 4.0 and
    below.
  * Fix issue with ``@admin.register()`` checker
* Mon Sep 11 2023 Dirk Müller <dmueller@suse.com>
- update to 1.14.1:
  * Fix bug in ``STORAGES`` fixer when only one of
    ``DEFAULT_FILE_STORAGE`` or ``STATICFILES_STORAGE`` was
    defined.
* Tue Jul 11 2023 Dirk Müller <dmueller@suse.com>
- update to 1.14.0:
  * Support Python 3.12.
* Thu Mar 30 2023 Dirk Müller <dmueller@suse.com>
- update to 1.13.0:
  * Add Django 4.2+ fixer to combine deprecated
    ``DEFAULT_FILE_STORAGE`` and ``STATICFILES_STORAGE`` settings
    into the new ``STORAGES`` setting.
  * Add Django 4.2+ fixer to rewrite HTTP headers passed to test
    ``Client`` and ``RequestFactory``.
  * Add Django 4.2+ fixer to rewrite test case methods
    ``assertFormsetError()`` and ``assertQuerysetEqual()`` into
    the new spellings with capitalized “Set”.
  * Add Django 4.0 fixer to rewrite
    ``django.contrib.admin.utils.lookup_needs_distinct`` ->
    ``lookup_spawns_duplicates``.
  * Rewrite ``request.META`` -> ``request.headers`` on the *right
    hand side* of assignments.
  * Group some compatibility import replacements into a single
    “fixer”, optimizing runtime by about 3%%.
* Fri Jan 20 2023 Dirk Müller <dmueller@suse.com>
- update to 1.12.0:
  * Make ``re_path`` -> ``path`` fixer also convert ``include()``\'s with
    unterminated regexes.
  * Avoid rewriting ``request.META`` to ``request.headers`` in ``del``
    statements.
  * Add Django 1.9+ fixer to rename the legacy engine name
    ``django.db.backends.postgresql_psycopg2`` in ``settings.DATABASES`` to
    ``django.db.backends.postgresql``.
  * Make detection of management commands and migration files detect both
    forward and backward slashes as directory separators.
- update to 1.11.0:
  * See also `the release blog post
    <https://adamj.eu/tech/2022/10/26/django-upgrade-mega-release/>`__.
  * Add Django 1.7+ fixer to rewrite ``admin.site.register()`` calls into
    ``@admin.register()`` when eligible.
  * Add Django 3.2+ fixer to rewrite admin action function attributes to use
    the ``@admin.action()`` decorator.
  * Add Django 3.2+ fixer to rewrite admin display function attributes to
    use the ``@admin.display()`` decorator.
  * Add Django 4.1+ fixer to rewrite calls to test case methods
    ``assertFormError()`` and ``assertFormsetError()`` from their old
    signatures to the new ones.
  * Add Django 2.0+ fixer to drop assignments of ``allow_tags`` attributes
    to ``True``.
  * Add Django 3.1+ fixer to replace ``list`` error message key with
    ``list_invalid`` on ``ModelMultipleChoiceField``.
  * Make ``request.headers`` fixer also rewrite accesses of the ``content-
    length`` and ``content-type`` headers.
  * Extend ``request.headers`` fixer to rewrite ``in`` and ``not in``
    comparisons on ``request.META``.
  * The ``request.headers`` fixer now uses lowercase for header lookups, as
    per the HTTP/2 specification.
  * Make ``on_delete`` fixer also support ``ForeignKey`` and
    ``OneToOneField`` imported from ``django.db.models``.
  * Make ``NullBooleanField`` fixer preserve existing ``null`` arguments.
  * Update ``timezone.utc`` fixer to only use absolute references from
    existing imports of the ``datetime`` module.
  * Make Django 2.0+ URL fixer avoid a loop of adding imports that already
    exist.
  * Fixers that modify string literals now match existing use of double
    quotes.
  * Make fixers that erase lines also erase any trailing comments.
  * Fix leaving a trailing comma when editing imports in certain cases.
  * Expand the range of files considered settings files.
  * Require at least one filename.
  * Update README with info on how to run an upgrade on entire project.
- update to 1.10.0:
  * Add Django 3.2+ fixer to update ``requires_system_checks`` in management
    command classes.
* Thu Sep  1 2022 John Vandenberg <jayvdb@gmail.com>
- Update to v1.9.0
* Sun Dec 26 2021 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.4.0
